/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.editpart.policy;

import java.util.List;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.CompoundCommand;
import org.eclipse.gef.commands.UnexecutableCommand;
import org.eclipse.gef.editpolicies.ComponentEditPolicy;
import org.eclipse.gef.requests.GroupRequest;
import org.fortiss.tooling.kernel.model.IRemovable;

/**
 * An edit policy for {@link IRemovable}. This is not a singleton, as the
 * editpart will call various setters on its instance.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 2B5B416E8F269FF00EC78D0226A479BA
 */
public final class RemoveEditPolicy extends ComponentEditPolicy {

	/** {@inheritDoc} */
	@SuppressWarnings("unchecked")
	@Override
	public Command createDeleteCommand(GroupRequest request) {
		CompoundCommand compound = new CompoundCommand();
		for (EditPart ep : (List<EditPart>) request.getEditParts()) {
			if (!(ep.getModel() instanceof IRemovable)) {
				return UnexecutableCommand.INSTANCE;
			}
			compound.add(new RemoveCommand((IRemovable) ep.getModel()));
		}
		return compound;
	}

	/** The command class used for removing. */
	public static class RemoveCommand extends Command {

		/** The entity to be removed. */
		private final IRemovable toRemove;

		/** Creates a command to remove a subcomponent. */
		public RemoveCommand(IRemovable toRemove) {
			this.toRemove = toRemove;
		}

		/** {@inheritDoc} */
		@Override
		public void execute() {
			toRemove.remove();
		}

		/** {@inheritDoc} */
		@Override
		public boolean canExecute() {
			return toRemove.canRemove();
		}
	}
}
