/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.internal.command;

import org.eclipse.gef.commands.Command;

/**
 * This class wraps an EMF command in a GEF command.
 * 
 * @author hummel
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: D6B33EFB704B0CA151E1C945B5BC48C6
 */
public class EMF2GEFCommand extends Command {

	/** The wrapped command. */
	private final org.eclipse.emf.common.command.Command emfCommand;

	/** Constructor. */
	public EMF2GEFCommand(org.eclipse.emf.common.command.Command emfCommand) {
		this.emfCommand = emfCommand;
	}

	/** {@inheritDoc} */
	@Override
	public boolean canExecute() {
		return emfCommand.canExecute();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canUndo() {
		return emfCommand.canUndo();
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		emfCommand.dispose();
		super.dispose();
	}

	/** {@inheritDoc} */
	@Override
	public void execute() {
		emfCommand.execute();
	}

	/** {@inheritDoc} */
	@Override
	public String getLabel() {
		return emfCommand.getLabel();
	}

	/** {@inheritDoc} */
	@Override
	public void redo() {
		emfCommand.redo();
	}

	/**
	 * {@inheritDoc}
	 * 
	 * @throws UnsupportedOperationException
	 *             as this is not supported.
	 */
	@Override
	public void setLabel(String label) {
		throw new UnsupportedOperationException();
	}

	/** {@inheritDoc} */
	@Override
	public void undo() {
		emfCommand.undo();
	}
}
