/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.internal.command;

import java.util.Collection;
import java.util.Collections;

import org.eclipse.emf.common.command.Command;
import org.eclipse.emf.common.command.CompoundCommand;

/**
 * This class wraps a GEF command in an EMF command.
 * 
 * @author hummel
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: D6B33EFB704B0CA151E1C945B5BC48C6
 */
public class GEF2EMFCommand implements Command {

	/** The wrapped command. */
	private final org.eclipse.gef.commands.Command gefCommand;

	/** Constructor. */
	public GEF2EMFCommand(org.eclipse.gef.commands.Command gefCommand) {
		this.gefCommand = gefCommand;
	}

	/** {@inheritDoc} */
	@Override
	public boolean canExecute() {
		return gefCommand.canExecute();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canUndo() {
		return gefCommand.canUndo();
	}

	/** {@inheritDoc} */
	@Override
	public Command chain(Command command) {
		if (command == null) {
			return this;
		}

		CompoundCommand result = new CompoundCommand();
		result.append(this);
		result.append(command);
		return result;
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		gefCommand.dispose();
	}

	/** {@inheritDoc} */
	@Override
	public void execute() {
		gefCommand.execute();
	}

	/** {@inheritDoc} */
	@Override
	public Collection<?> getAffectedObjects() {
		return Collections.EMPTY_LIST;
	}

	/** {@inheritDoc} */
	@Override
	public String getDescription() {
		return gefCommand.getLabel();
	}

	/** {@inheritDoc} */
	@Override
	public String getLabel() {
		return gefCommand.getLabel();
	}

	/** {@inheritDoc} */
	@Override
	public Collection<?> getResult() {
		return Collections.EMPTY_LIST;
	}

	/** {@inheritDoc} */
	@Override
	public void redo() {
		gefCommand.redo();
	}

	/** {@inheritDoc} */
	@Override
	public void undo() {
		gefCommand.undo();
	}
}
