/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.internal.command;

import java.util.EventObject;

import org.eclipse.emf.common.command.CommandStackListener;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.CommandStack;

/**
 * This command stack wraps an EMF command stack. Execute, undo and redo are
 * forwarded, as well as the listener stuff. Note that the dirty state and save
 * location are <b>not</b> forwarded, i.e. the underlying editing domain should
 * be used directly for this.
 * 
 * @author hummel
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash: D6B33EFB704B0CA151E1C945B5BC48C6
 */
public class GEF2EMFCommandStack extends CommandStack implements
		CommandStackListener {

	/** The wrapped command stack. */
	private final org.eclipse.emf.common.command.CommandStack emfCommandStack;

	/** Constructor. */
	public GEF2EMFCommandStack(
			org.eclipse.emf.common.command.CommandStack emfCommandStack) {
		this.emfCommandStack = emfCommandStack;
		emfCommandStack.addCommandStackListener(this);
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		emfCommandStack.removeCommandStackListener(this);
		super.dispose();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canRedo() {
		return emfCommandStack.canRedo();
	}

	/** {@inheritDoc} */
	@Override
	public boolean canUndo() {
		return emfCommandStack.canUndo();
	}

	/** {@inheritDoc} */
	@Override
	public void execute(Command command) {
		emfCommandStack.execute(new GEF2EMFCommand(command));
	}

	/** {@inheritDoc} */
	@Override
	public Command getRedoCommand() {
		return new EMF2GEFCommand(emfCommandStack.getRedoCommand());
	}

	/** {@inheritDoc} */
	@Override
	public Command getUndoCommand() {
		return new EMF2GEFCommand(emfCommandStack.getUndoCommand());
	}

	/** {@inheritDoc} */
	@Override
	public void redo() {
		emfCommandStack.redo();
	}

	/** {@inheritDoc} */
	@Override
	public void undo() {
		emfCommandStack.undo();
	}

	/** {@inheritDoc} */
	@Override
	@SuppressWarnings("deprecation")
	public void commandStackChanged(EventObject event) {
		notifyListeners();
	}
}
