/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.layout.constants;

import org.conqat.ide.commons.ui.swt.FontUtils;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Font;

/**
 * Default layout constants for GEF-based editors.
 * 
 * @author wandinger
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: B39B2B4E72E7414FABE88CBE9DF54EEE
 */
public final class RecommendedLayoutConstants {

	/** Title font. */
	public static final Font TITLE_FONT = FontUtils.derive(
			JFaceResources.getDefaultFont(), 0, SWT.BOLD);

	// editor grid constants

	/** The offset of the grid. */
	public static final Point GRID_ORIGIN = new Point(0, 0);

	/** The size between two lines of the grid. */
	public static final int GRID_SIZE = 12;

	// oval shapes constants

	/** The size of oval connectors. */
	public static final int OVAL_CONNECTOR_SIZE = GRID_SIZE * 2;

	/** Dimension used for oval connectors. */
	public static final Dimension OVAL_CONNECTOR_DIMENSION = new Dimension(
			OVAL_CONNECTOR_SIZE, OVAL_CONNECTOR_SIZE);

	/** The minimal height of an oval shape. */
	public static final int OVAL_SHAPE_MINIMUM_HEIGHT = GRID_SIZE * 6;

	/** The aspect ratio of oval shapes. */
	public static final double OVAL_SHAPE_ASPECT_RATIO = 1.6;

	/** The minimal width of an oval shape. */
	public static final int OVAL_SHAPE_MINIMUM_WIDTH = (int) (OVAL_SHAPE_MINIMUM_HEIGHT * OVAL_SHAPE_ASPECT_RATIO);

	// rectangular shapes constants

	/** The minimum width of a rectangular shape. */
	public static final int RECTANGULAR_SHAPE_MINIMUM_WIDTH = 9 * GRID_SIZE;

	/** The minimum height of a rectangular shape. */
	public static final int RECTANGULAR_SHAPE_MINIMUM_HEIGHT = 6 * GRID_SIZE;

	/** The size of the insets of a rectangular shape. */
	public static final int RECTANGULAR_SHAPE_INSETS = GRID_SIZE;

	/** The size of a rectangular connector. */
	public static final int RECTANGULAR_CONNECTOR_SIZE = 2 * GRID_SIZE;

	/** Dimension used for rectangular connector. */
	public static final Dimension RECTANGULAR_CONNECTOR_DIMENSION = new Dimension(
			RECTANGULAR_CONNECTOR_SIZE, RECTANGULAR_CONNECTOR_SIZE);

	/** The bounds used for the main figure of the rectangular connector. */
	public static final Rectangle RECTANGULAR_CONNECTOR_FIGURE_BOUNDS = new Rectangle(
			RECTANGULAR_CONNECTOR_SIZE / 4, RECTANGULAR_CONNECTOR_SIZE / 4,
			RECTANGULAR_CONNECTOR_SIZE / 2, RECTANGULAR_CONNECTOR_SIZE / 2);
}
